![PyPI version](https://badge.fury.io/py/namemcpy.svg)[![PyPI license](https://img.shields.io/pypi/l/namemcpy.svg) ![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
# About📄
namemcpy is a api wrapper for [namemc](https://namemc.com)
Some features of this scrape the website and potentially break if the websites changes.

# How to install💾

`pip install namemcpy`
or

`pip3 install namemcpy`
or

`pip3 install -r install.txt`

or just run the .bat file in the install folder.

# Usage (WIP) ✏️

For usage check out the USAGE.md.

  # Credits❤️
Anyone who contributes gets added if I have not added you please email me. To all the contributers thank you so much support I would not be here without all of you. ❤️

[lasscat](https://github.com/lasscat)

[BluCobalt](https://github.com/BluCobalt)


# TODO 🧠 (my personal stuff todo excuse my grammar)
nothing much
